@@ -22,11 +22,13 @@ import logging.config
 import logging.handlers
 import os
 import sys
+import tempfile
 
 from oslo.config import cfg
 from paste import deploy
 
 from muranoconductor import __version__ as version
+from muranoconductor.openstack.common import log
 from ConfigParser import SafeConfigParser
 
 paste_deploy_opts = [
@@ -34,6 +36,13 @@ paste_deploy_opts = [
     cfg.StrOpt('config_file'),
 ]
 
+directories = [
+    cfg.StrOpt('data_dir', default=os.path.join(tempfile.gettempdir(),
+                                                'muranoconductor-cache')),
+    cfg.StrOpt('init_scripts_dir', default='etc/init-scripts'),
+    cfg.StrOpt('agent_config_dir', default='etc/agent-config'),
+]
+
 rabbit_opts = [
     cfg.StrOpt('host', default='localhost'),
     cfg.IntOpt('port', default=5672),
@@ -52,7 +61,7 @@ heat_opts = [
     cfg.StrOpt('endpoint_type', default='publicURL')
 ]
 
-quantum_opts = [
+neutron_opts = [
     cfg.BoolOpt('insecure', default=False),
     cfg.StrOpt('ca_cert'),
     cfg.StrOpt('endpoint_type', default='publicURL')
@@ -70,12 +79,19 @@ CONF = cfg.CONF
 CONF.register_opts(paste_deploy_opts, group='paste_deploy')
 CONF.register_opts(rabbit_opts, group='rabbitmq')
 CONF.register_opts(heat_opts, group='heat')
-CONF.register_opts(quantum_opts, group='quantum')
+CONF.register_opts(neutron_opts, group='neutron')
 CONF.register_opts(keystone_opts, group='keystone')
+CONF.register_opts(directories)
 CONF.register_opt(cfg.StrOpt('file_server'))
-CONF.register_cli_opt(cfg.StrOpt('data_dir', default='./'))
+CONF.register_cli_opt(cfg.StrOpt('murano_metadata_url'))
+
 
 CONF.register_opt(cfg.IntOpt('max_environments', default=20))
+CONF.register_opt(cfg.IntOpt('max_hosts', default=250))
+CONF.register_opt(cfg.StrOpt('env_ip_template', default='10.0.0.0'))
+CONF.register_opt(cfg.StrOpt('network_topology',
+                             choices=['nova', 'flat', 'routed'],
+                             default='routed'))
 
 
 CONF.import_opt('verbose', 'muranoconductor.openstack.common.log')
@@ -89,6 +105,12 @@ CONF.import_opt('use_syslog', 'muranoconductor.openstack.common.log')
 CONF.import_opt('syslog_log_facility', 'muranoconductor.openstack.common.log')
 
 
+cfg.set_defaults(log.log_opts, default_log_levels=[
+    'iso8601=WARN',
+    'heatclient=WARN'
+])
+
+
 def parse_args(args=None, usage=None, default_config_files=None):
     CONF(args=args,
          project='conductor',
