@@ -31,8 +31,10 @@ class TestHeatExecutor(unittest.TestCase):
                 "$key": "$value"
             }
         }
+        self.metadata_id = 'b5bbea94023083e1ee06a52af5663b15c1fb1b7c'
         self.mfs.add_entries({
-            './data/templates/cf/test.template': json.dumps(template)})
+            './{0}/templates/cf/test.template'.format(self.metadata_id):
+            json.dumps(template)})
 
     def tearDown(self):
         mockfs.restore_builtins()
@@ -42,22 +44,15 @@ class TestHeatExecutor(unittest.TestCase):
 
         auth_data = ksclient_mock().tokens.authenticate()
         auth_data.id = '123456'
-        auth_data.serviceCatalog = [
-            {
-                'name': 'heat',
-                'endpoints': [{'publicURL': 'http://invalid.heat.url'}]
-            }, {
-                'name': 'quantum',
-                'endpoints': [{'publicURL': 'http://invalid.quantum.url'}]
-            }
-        ]
+        auth_data.serviceCatalog = [{
+            'name': 'heat',
+            'endpoints': [{'publicURL': 'http://invalid.heat.url'}]
+        }]
 
-    @mock.patch('quantumclient.v2_0.client.Client')
     @mock.patch('heatclient.v1.client.Client')
     @mock.patch('keystoneclient.v2_0.client.Client')
     @mock.patch('muranoconductor.config.CONF')
-    def test_create_stack(self, config_mock, ksclient_mock, heat_mock,
-                          quantum_mock):
+    def test_create_stack(self, config_mock, ksclient_mock, heat_mock):
         self._init(config_mock, ksclient_mock)
         reporter = mock.MagicMock()
         executor = HeatExecutor('stack', 'token', 'tenant_id', reporter)
@@ -73,7 +68,8 @@ class TestHeatExecutor(unittest.TestCase):
             arguments={
                 'arg1': 'arg1Value',
                 'arg2': 'arg2Value'},
-            callback=callback)
+            callback=callback,
+            metadata_id=self.metadata_id)
 
         heat_mock().stacks.get().stack_status = 'CREATE_COMPLETE'
         heat_mock().stacks.template = mock.MagicMock(
@@ -95,12 +91,10 @@ class TestHeatExecutor(unittest.TestCase):
             disable_rollback=False)
         callback.assert_called_with({})
 
-    @mock.patch('quantumclient.v2_0.client.Client')
     @mock.patch('heatclient.v1.client.Client')
     @mock.patch('keystoneclient.v2_0.client.Client')
     @mock.patch('muranoconductor.config.CONF')
-    def test_update_stack(self, config_mock, ksclient_mock, heat_mock,
-                          quantum_mock):
+    def test_update_stack(self, config_mock, ksclient_mock, heat_mock):
         self._init(config_mock, ksclient_mock)
         reporter = mock.MagicMock()
         executor = HeatExecutor('stack', 'token', 'tenant_id', reporter)
@@ -116,7 +110,8 @@ class TestHeatExecutor(unittest.TestCase):
             arguments={
                 'arg1': 'arg1Value',
                 'arg2': 'arg2Value'},
-            callback=callback)
+            callback=callback,
+            metadata_id=self.metadata_id)
 
         get_mock = heat_mock().stacks.get()
         get_mock.stack_name = 'stack'
